==> haskell-tabular-0.2.2.7-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tabular.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tabular
version: 0.2.2.7
id: tabular-0.2.2.7-5b7MGmRWrPsD9aeDanGUHj
key: tabular-0.2.2.7-5b7MGmRWrPsD9aeDanGUHj
license: BSD3
maintainer: Eric Kow <eric.kow@gmail.com>
homepage: http://hub.darcs.net/kowey/tabular
synopsis: Two-dimensional data tables with rendering functions
description:
    Tabular provides a Haskell representation of two-dimensional
    data tables, the kind that you might find in a spreadsheet or
    or a research report.  It also comes with some default
    rendering functions for turning those tables into ASCII art,
    simple text with an arbitrary delimiter, CSV, HTML or LaTeX.
    .
    Below is an example of the kind of output this library produces.
    The tabular package can group rows and columns, each group
    having one of three separators (no line, single line, double line)
    between its members.
    .
    >     || memtest 1 | memtest 2 ||  time test  | time test 2
    > ====++===========+===========++=============+============
    > A 1 ||       hog |  terrible ||        slow |      slower
    > A 2 ||       pig |   not bad ||        fast |     slowest
    > ----++-----------+-----------++-------------+------------
    > B 1 ||      good |     awful || intolerable |    bearable
    > B 2 ||    better | no chance ||    crawling |     amazing
    > B 3 ||       meh |   well... ||  worst ever |          ok
category: Text
author: Eric Kow
exposed: True
indefinite: False
exposed-modules:
    Text.Tabular Text.Tabular.AsciiArt Text.Tabular.Csv
    Text.Tabular.Html Text.Tabular.Latex Text.Tabular.SimpleText
abi: d6fdb2962e98e2267595bafb1275c15b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tabular-0.2.2.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/tabular-0.2.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/tabular-0.2.2.7
hs-libraries: HStabular-0.2.2.7-5b7MGmRWrPsD9aeDanGUHj
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    csv-0.1.2-DF8z6jUOfpiBCBTUDP7ddT
    html-1.0.1.2-HJx3nTTgwhH7I2VQDflUHM
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             csv-0.1.2-DF8z6jUOfpiBCBTUDP7ddT=be166ca37d31f068df6973a78755b37e
             html-1.0.1.2-HJx3nTTgwhH7I2VQDflUHM=694e2acdc878f8e5397e003a5fb1ea2f
haddock-interfaces: /usr/share/doc/haskell-tabular/html/tabular.haddock
haddock-html: /usr/share/doc/haskell-tabular/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tabular-0.2.2.7-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tabular.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tabular
version: 0.2.2.7
id: tabular-0.2.2.7-28788Jqsw9Bkc0Il5IXc2
key: tabular-0.2.2.7-28788Jqsw9Bkc0Il5IXc2
license: BSD3
maintainer: Eric Kow <eric.kow@gmail.com>
homepage: http://hub.darcs.net/kowey/tabular
synopsis: Two-dimensional data tables with rendering functions
description:
    Tabular provides a Haskell representation of two-dimensional
    data tables, the kind that you might find in a spreadsheet or
    or a research report.  It also comes with some default
    rendering functions for turning those tables into ASCII art,
    simple text with an arbitrary delimiter, CSV, HTML or LaTeX.
    .
    Below is an example of the kind of output this library produces.
    The tabular package can group rows and columns, each group
    having one of three separators (no line, single line, double line)
    between its members.
    .
    >     || memtest 1 | memtest 2 ||  time test  | time test 2
    > ====++===========+===========++=============+============
    > A 1 ||       hog |  terrible ||        slow |      slower
    > A 2 ||       pig |   not bad ||        fast |     slowest
    > ----++-----------+-----------++-------------+------------
    > B 1 ||      good |     awful || intolerable |    bearable
    > B 2 ||    better | no chance ||    crawling |     amazing
    > B 3 ||       meh |   well... ||  worst ever |          ok
category: Text
author: Eric Kow
exposed: True
indefinite: False
exposed-modules:
    Text.Tabular Text.Tabular.AsciiArt Text.Tabular.Csv
    Text.Tabular.Html Text.Tabular.Latex Text.Tabular.SimpleText
abi: 8026e4a20a716592c129f597aff1f6d6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tabular-0.2.2.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/tabular-0.2.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/tabular-0.2.2.7
hs-libraries: HStabular-0.2.2.7-28788Jqsw9Bkc0Il5IXc2
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    csv-0.1.2-I4gcangUQPN5j1xlMcytF8
    html-1.0.1.2-HJx3nTTgwhH7I2VQDflUHM
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             csv-0.1.2-I4gcangUQPN5j1xlMcytF8=2d03fd6745e50a614262bbdc40354308
             html-1.0.1.2-HJx3nTTgwhH7I2VQDflUHM=694e2acdc878f8e5397e003a5fb1ea2f
haddock-interfaces: /usr/share/doc/haskell-tabular/html/tabular.haddock
haddock-html: /usr/share/doc/haskell-tabular/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
